@@ -1,5 +1,5 @@
-from data_clean import *
-from dataframe_checking import *
+from insightsearch.data_clean import *
+from insightsearch.dataframe_checking import *
 from pathlib import Path
 
 class Analysis(DataframeClean):
@@ -17,10 +17,4 @@ class Analysis(DataframeClean):
         self.showing_sentiment()
 
 
-a = Analysis(
-    str(Path(__file__).parent.parent) +'/saved/All_Beauty_5.csv',
-    "reviewText",
-    "reviewTime",False
-)
 
-a.review_analyze()
